@@ -259,9 +259,10 @@ def set_model_params(X, y):
     checkpoint = ModelCheckpoint(filepath, monitor='loss', verbose=1, save_best_only=True, mode='min')
     desired_callbacks = [checkpoint]
     model.fit(X, y, epochs=5, batch_size=200, callbacks=desired_callbacks)
+    return model
 
 
-def what_does_the_robot_say(filename):
+def what_does_the_robot_say(filename, model):
     filename = "model_weights_saved.hdf5"
     model.load_weights(filename)
     model.compile(loss='categorical_crossentropy', optimizer='adam')
