@@ -15,7 +15,17 @@ import subprocess
 def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
+try:
 
+    import pixplot
+
+except BaseException as e:
+    print("Keras Tensorflor Backend Failled With Error: ", e)
+    print("Using most recent tensorflow keras backend...")
+    install('pixplot')
+    import pixplot
+
+    print("Success! :)")
 try:
 
     from keras.backend.tensorflow_backend import set_session
@@ -25,6 +35,8 @@ except BaseException as e:
     from tensorflow.compat.v1.keras.backend import set_session
 
     print("Success! :)")
+
+
 try:
     from pointgrid import align_points_to_grid
 
@@ -1059,7 +1071,7 @@ def write_images(**kwargs):
 
 def get_version():
     '''Return the version of pixplot installed'''
-    return pkg_resources.get_distribution('JATA').version
+    return pkg_resources.get_distribution('pixplot').version
 
 
 class Image:
